pub fn add_auditor(
install_options: AddAuditorServiceOptions,
node_registry: &mut NodeRegistry,
service_control: &dyn ServiceControl,
verbosity: VerbosityLevel,
) -> Result<()>Expand description
Install the auditor as a service.
This only defines the service; it does not start it.
There are several arguments that probably seem like they could be handled within the function, but they enable more controlled unit testing.